jenkins-bot has submitted this change. ( 
https://gerrit.wikimedia.org/r/c/pywikibot/core/+/935669 )

Change subject: [8.2] Publish Pywikibot 8.2
......................................................................

[8.2] Publish Pywikibot 8.2

Also update ROADMAP.rst and remove plain 'Allocator.' docstring.

Change-Id: Ie36d071088debc38f9f0b30310d48ab6aae50e5e
---
M ROADMAP.rst
M docs/conf.py
M pywikibot/__metadata__.py
3 files changed, 21 insertions(+), 3 deletions(-)

Approvals:
  Xqt: Looks good to me, approved
  jenkins-bot: Verified




diff --git a/ROADMAP.rst b/ROADMAP.rst
index 3ddf33e..e4f6b4c 100644
--- a/ROADMAP.rst
+++ b/ROADMAP.rst
@@ -1,6 +1,8 @@
 Current release
 ---------------

+* Add support for gpewiki (:phab:`T335989`)
+* :class:`family.WikibaseFamily` and :class:`family.DefaultWikibaseFamily` 
were added to :mod:`family` module
 * Remove incorrect time normalization in :class:`page.Claim` (:phab:`T338748`, 
:phab:`T325860`, :phab:`T57755`)
 * Add support for other types of diffs in 
:meth:`Site.compare()<pywikibot.site._apisite.APISite.compare>`
 * Improvements for :func:`textlib.extract_sections` function (:phab:`T338748`)
@@ -26,6 +28,7 @@
 Deprecations
 ------------

+* 8.2.0: *normalize* parameter of :meth:`WbTime.toTimestr` and 
:meth:`WbTime.toWikibase` will be removed
 * 8.1.0: Dependency of :exc:`exceptions.NoSiteLinkError` from 
:exc:`exceptions.NoPageError` will be removed
 * 8.1.0: ``exceptions.Server414Error`` is deprecated in favour of 
:exc:`exceptions.Client414Error`
 * 8.0.0: :meth:`Timestamp.clone()<pywikibot.time.Timestamp.clone>` method is 
deprecated
diff --git a/pywikibot/__metadata__.py b/pywikibot/__metadata__.py
index e186959..e6ff22a 100644
--- a/pywikibot/__metadata__.py
+++ b/pywikibot/__metadata__.py
@@ -11,7 +11,7 @@


 __name__ = 'pywikibot'
-__version__ = '8.2.0.dev2'
+__version__ = '8.2.0'
 __description__ = 'Python MediaWiki Bot Framework'
 __maintainer__ = 'The Pywikibot team'
 __maintainer_email__ = '[email protected]'

diff --git a/docs/conf.py b/docs/conf.py
index 6a3f9c2..e29746b 100644
--- a/docs/conf.py
+++ b/docs/conf.py
@@ -504,11 +504,15 @@


 def pywikibot_docstring_fixups(app, what, name, obj, options, lines):
-    """Remove plain 'Initializer.' docstring."""
+    """Remove plain 'Initializer.' or 'Allocator.' docstring.
+
+    .. versionchanged:: 8.2
+       remove 'Allocator.' docstring too.
+    """
     if what not in ('class', 'exception'):
         return

-    if lines and lines[0] == 'Initializer.':
+    if lines and lines[0] in ('Initializer.', 'Allocator.'):
         lines[:] = lines[2:]


--
To view, visit https://gerrit.wikimedia.org/r/c/pywikibot/core/+/935669
To unsubscribe, or for help writing mail filters, visit 
https://gerrit.wikimedia.org/r/settings

Gerrit-Project: pywikibot/core
Gerrit-Branch: master
Gerrit-Change-Id: Ie36d071088debc38f9f0b30310d48ab6aae50e5e
Gerrit-Change-Number: 935669
Gerrit-PatchSet: 1
Gerrit-Owner: Xqt <[email protected]>
Gerrit-Reviewer: Xqt <[email protected]>
Gerrit-Reviewer: jenkins-bot
Gerrit-MessageType: merged
_______________________________________________
Pywikibot-commits mailing list -- [email protected]
To unsubscribe send an email to [email protected]

Reply via email to